pub struct Client { /* private fields */ }Expand description
Client for Lybic core API
Lybic core API
Version: 1.0
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(baseurl: &str) -> Self
pub fn new(baseurl: &str) -> Self
Create a new client.
baseurl is the base URL provided to the internal
reqwest::Client, and should include a scheme and hostname,
as well as port and a path stem if applicable.
Sourcepub fn new_with_client(baseurl: &str, client: Client) -> Self
pub fn new_with_client(baseurl: &str, client: Client) -> Self
Construct a new client with an existing reqwest::Client,
allowing more control over its configuration.
baseurl is the base URL provided to the internal
reqwest::Client, and should include a scheme and hostname,
as well as port and a path stem if applicable.
Sourceimpl Client
impl Client
Sourcepub async fn list_mcp_servers<'a>(
&'a self,
org_id: &'a str,
) -> Result<ResponseValue<ListMcpServerResponse>, Error<()>>
pub async fn list_mcp_servers<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<ListMcpServerResponse>, Error<()>>
List MCP servers
Returns a list of MCP servers for the organization.
Sends a GET request to /api/orgs/{orgId}/mcp-servers
Arguments:
org_id: The organization ID
Sourcepub async fn create_mcp_server<'a>(
&'a self,
org_id: &'a str,
body: &'a CreateMcpServerDto,
) -> Result<ResponseValue<McpServerResponseDto>, Error<()>>
pub async fn create_mcp_server<'a>( &'a self, org_id: &'a str, body: &'a CreateMcpServerDto, ) -> Result<ResponseValue<McpServerResponseDto>, Error<()>>
Create MCP server
Creates a new MCP server.
Sends a POST request to /api/orgs/{orgId}/mcp-servers
Arguments:
org_id: The organization IDbody
Sourcepub async fn get_default_mcp_server<'a>(
&'a self,
org_id: &'a str,
) -> Result<ResponseValue<McpServerResponseDto>, Error<()>>
pub async fn get_default_mcp_server<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<McpServerResponseDto>, Error<()>>
Get Default MCP server
Returns the default MCP server for the organization. If not set, it will create a new one.
Sends a GET request to /api/orgs/{orgId}/mcp-servers/default
Arguments:
org_id: The organization ID
Sourcepub async fn delete_mcp_server<'a>(
&'a self,
org_id: &'a str,
mcp_server_id: &'a str,
) -> Result<ResponseValue<()>, Error<()>>
pub async fn delete_mcp_server<'a>( &'a self, org_id: &'a str, mcp_server_id: &'a str, ) -> Result<ResponseValue<()>, Error<()>>
Delete MCP server
Deletes an MCP server by its ID.
Sends a DELETE request to /api/orgs/{orgId}/mcp-servers/{mcpServerId}
Arguments:
org_id: The organization IDmcp_server_id
Sourcepub async fn set_mcp_server_to_sandbox<'a>(
&'a self,
org_id: &'a str,
mcp_server_id: &'a str,
body: &'a SetMcpServerToSandboxResponseDto,
) -> Result<ResponseValue<()>, Error<()>>
pub async fn set_mcp_server_to_sandbox<'a>( &'a self, org_id: &'a str, mcp_server_id: &'a str, body: &'a SetMcpServerToSandboxResponseDto, ) -> Result<ResponseValue<()>, Error<()>>
Set MCP server to Sandbox
Sets the specified MCP server to the given Sandbox.
Sends a POST request to /api/orgs/{orgId}/mcp-servers/{mcpServerId}/sandbox
Arguments:
org_id: The organization IDmcp_server_idbody
Sourcepub async fn list_sandboxes<'a>(
&'a self,
org_id: &'a str,
) -> Result<ResponseValue<SandboxListResponseDto>, Error<()>>
pub async fn list_sandboxes<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<SandboxListResponseDto>, Error<()>>
List Sandboxes
Returns a list of sandboxes for the organization.
Sends a GET request to /api/orgs/{orgId}/sandboxes
Arguments:
org_id: The organization ID
Sourcepub async fn create_sandbox<'a>(
&'a self,
org_id: &'a str,
body: &'a CreateSandboxDto,
) -> Result<ResponseValue<CreateSandboxResponseDto>, Error<()>>
pub async fn create_sandbox<'a>( &'a self, org_id: &'a str, body: &'a CreateSandboxDto, ) -> Result<ResponseValue<CreateSandboxResponseDto>, Error<()>>
Create Sandbox
Creates a new sandbox.
Sends a POST request to /api/orgs/{orgId}/sandboxes
Arguments:
org_id: The organization IDbody
Sourcepub async fn copy_files_with_sandbox<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
body: &'a SandboxFileCopyRequestDto,
) -> Result<ResponseValue<SandboxFileCopyResponseDto>, Error<()>>
pub async fn copy_files_with_sandbox<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, body: &'a SandboxFileCopyRequestDto, ) -> Result<ResponseValue<SandboxFileCopyResponseDto>, Error<()>>
Copy Sandbox Files
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/file/copy
Arguments:
org_id: The organization IDsandbox_idbody
Sourcepub async fn exec_sandbox_process<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
body: &'a SandboxProcessRequestDto,
) -> Result<ResponseValue<SandboxProcessResponseDto>, Error<()>>
pub async fn exec_sandbox_process<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, body: &'a SandboxProcessRequestDto, ) -> Result<ResponseValue<SandboxProcessResponseDto>, Error<()>>
Execute Command in Sandbox
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/process
Arguments:
org_id: The organization IDsandbox_idbody
Sourcepub async fn get_sandbox<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
) -> Result<ResponseValue<GetSandboxResponseDto>, Error<()>>
pub async fn get_sandbox<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, ) -> Result<ResponseValue<GetSandboxResponseDto>, Error<()>>
Get Sandbox Details
Get the sandbox details by id
Sends a GET request to /api/orgs/{orgId}/sandboxes/{sandboxId}
Arguments:
org_id: The organization IDsandbox_id
Sourcepub async fn delete_sandbox<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
) -> Result<ResponseValue<()>, Error<()>>
pub async fn delete_sandbox<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, ) -> Result<ResponseValue<()>, Error<()>>
Delete Sandbox
Deletes a sandbox by its ID.
Sends a DELETE request to /api/orgs/{orgId}/sandboxes/{sandboxId}
Arguments:
org_id: The organization IDsandbox_id
Sourcepub async fn extend_sandbox<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
body: &'a ExtendSandboxDto,
) -> Result<ResponseValue<()>, Error<()>>
pub async fn extend_sandbox<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, body: &'a ExtendSandboxDto, ) -> Result<ResponseValue<()>, Error<()>>
Extend Sandbox
Extends a sandbox expire time by its ID.
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/extend
Arguments:
org_id: The organization IDsandbox_idbody
Sourcepub async fn execute_computer_use_action<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
body: &'a ComputerUseActionDto,
) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
pub async fn execute_computer_use_action<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, body: &'a ComputerUseActionDto, ) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
Execute Computer Use Action (Deprecated)
Deprecated, use executeSandboxAction instead
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/actions/computer-use
Arguments:
org_id: The organization IDsandbox_idbody
Sourcepub async fn execute_sandbox_action<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
body: &'a ExecuteSandboxActionDto,
) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
pub async fn execute_sandbox_action<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, body: &'a ExecuteSandboxActionDto, ) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
Execute Computer Use or Mobile Use action
Executes a computer use or mobile use action on the sandbox.
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/actions/execute
Arguments:
org_id: The organization IDsandbox_idbody
Sourcepub async fn preview_sandbox<'a>(
&'a self,
org_id: &'a str,
sandbox_id: &'a str,
) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
pub async fn preview_sandbox<'a>( &'a self, org_id: &'a str, sandbox_id: &'a str, ) -> Result<ResponseValue<SandboxActionResponseDto>, Error<()>>
Preview Sandbox
Takes a screenshot and gets cursor position of the sandbox.
Sends a POST request to /api/orgs/{orgId}/sandboxes/{sandboxId}/preview
Arguments:
org_id: The organization IDsandbox_id
Sourcepub async fn list_projects<'a>(
&'a self,
org_id: &'a str,
) -> Result<ResponseValue<ListProjectsResponseDto>, Error<()>>
pub async fn list_projects<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<ListProjectsResponseDto>, Error<()>>
List Projects
Returns a list of projects for the organization.
Sends a GET request to /api/orgs/{orgId}/projects
Arguments:
org_id: The organization ID
Sourcepub async fn create_project<'a>(
&'a self,
org_id: &'a str,
body: &'a CreateProjectDto,
) -> Result<ResponseValue<SingleProjectResponseDto>, Error<()>>
pub async fn create_project<'a>( &'a self, org_id: &'a str, body: &'a CreateProjectDto, ) -> Result<ResponseValue<SingleProjectResponseDto>, Error<()>>
Create Project
Creates a new project.
Sends a POST request to /api/orgs/{orgId}/projects
Arguments:
org_id: The organization IDbody
Sourcepub async fn delete_project<'a>(
&'a self,
org_id: &'a str,
project_id: &'a str,
) -> Result<ResponseValue<()>, Error<()>>
pub async fn delete_project<'a>( &'a self, org_id: &'a str, project_id: &'a str, ) -> Result<ResponseValue<()>, Error<()>>
Delete Project
Deletes a project by its ID.
Sends a DELETE request to /api/orgs/{orgId}/projects/{projectId}
Arguments:
org_id: The organization IDproject_id
Sourcepub async fn parse_model_output<'a>(
&'a self,
body: &'a ParseRequestDto,
) -> Result<ResponseValue<ComputerUseActionResponseDto>, Error<()>>
pub async fn parse_model_output<'a>( &'a self, body: &'a ParseRequestDto, ) -> Result<ResponseValue<ComputerUseActionResponseDto>, Error<()>>
Parse LLM Output (Deprecated)
Deprecated, use parseModelTextOutput instead
Sends a POST request to /api/computer-use/parse
Sourcepub async fn parse_model_text_output<'a>(
&'a self,
type_: ParseModelTextOutputType,
body: &'a ParseTextRequestDto,
) -> Result<ResponseValue<ComputerUseActionResponseDto>, Error<()>>
pub async fn parse_model_text_output<'a>( &'a self, type_: ParseModelTextOutputType, body: &'a ParseTextRequestDto, ) -> Result<ResponseValue<ComputerUseActionResponseDto>, Error<()>>
Parse LLM Text Output
Parses the output text of computer use model and returns the parsed actions.
Sends a POST request to /api/computer-use/parse/{type}
Arguments:
type_: The type of the prompt to parse the input forbody
Sourcepub async fn parse_mobile_use_model_text_output<'a>(
&'a self,
type_: ParseMobileUseModelTextOutputType,
body: &'a ParseTextRequestDto,
) -> Result<ResponseValue<MobileUseActionResponseDto>, Error<()>>
pub async fn parse_mobile_use_model_text_output<'a>( &'a self, type_: ParseMobileUseModelTextOutputType, body: &'a ParseTextRequestDto, ) -> Result<ResponseValue<MobileUseActionResponseDto>, Error<()>>
Parse Mobile Use Model Text Output
Parses the output text of mobile use model and returns the parsed actions.
Sends a POST request to /api/mobile-use/parse/{type}
Arguments:
type_: The type of the prompt to parse the input forbody
Sourcepub async fn get_stats<'a>(
&'a self,
org_id: &'a str,
) -> Result<ResponseValue<StatsResponseDto>, Error<()>>
pub async fn get_stats<'a>( &'a self, org_id: &'a str, ) -> Result<ResponseValue<StatsResponseDto>, Error<()>>
Get Organization Stats
Returns the stats of the organization, such as number of members, computers, etc.
Sends a GET request to /api/orgs/{orgId}/stats
Arguments:
org_id: The organization ID